@@ -192,10 +192,10 @@ def build_linked_list(arr: Union[List[T], str, None]) -> Optional[ListNode[T]]:
     if isinstance(arr, str):
         arr = json.loads(arr)
 
-    if not isinstance(arr, List) and arr is not None:
+    if not isinstance(arr, List):
         raise TypeError
 
-    if not arr:
+    if len(arr) == 0:
         return None
 
     head = ListNode(arr[0])
